# This file was auto-generated by Fern from our API Definition.

import typing
from .column_type_item_check_box import ColumnTypeItemCheckBox
from .column_type_item_json import ColumnTypeItemJson
from .column_type_item_number import ColumnTypeItemNumber
from .column_type_item_select import ColumnTypeItemSelect
from .column_type_item_text_long import ColumnTypeItemTextLong
from .column_type_item_text_short import ColumnTypeItemTextShort
from .column_type_item_url import ColumnTypeItemUrl

CollectionConfigInputColumnsItem = typing.Union[
    ColumnTypeItemCheckBox,
    ColumnTypeItemJson,
    ColumnTypeItemNumber,
    ColumnTypeItemSelect,
    ColumnTypeItemTextLong,
    ColumnTypeItemTextShort,
    ColumnTypeItemUrl,
]
