# This file was auto-generated by Fern from our API Definition.

import typing
from .document_content import DocumentContent

DocumentDataOutputContent = typing.Union[typing.List[DocumentContent], str]
