# This file was auto-generated by Fern from our API Definition.

import typing
from ...types.document_data_input import DocumentDataInput

DocumentsCreateRequest = typing.Union[DocumentDataInput, typing.List[DocumentDataInput]]
