# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class BlockRunUsage(UncheckedBaseModel):
    organization_id: typing.Optional[str] = None
    workflow_run_type: typing.Optional[str] = None
    block_archetype_id: typing.Optional[str] = None
    execution_date: typing.Optional[str] = None
    total_cost: float
    total_execution_duration_ms: typing.Optional[int] = None
    display_name: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
