# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .collection_config_output_columns_item import CollectionConfigOutputColumnsItem
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class CollectionConfigOutput(UncheckedBaseModel):
    collection_display_name: typing.Optional[str] = None
    collection_img_url: typing.Optional[str] = None
    collection_description: typing.Optional[str] = None
    columns: typing.Optional[typing.List[CollectionConfigOutputColumnsItem]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
