# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
from .environment_deployment_config import EnvironmentDeploymentConfig
import datetime as dt
from .identity import Identity
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic


class EnvironmentDeploymentDocument(UncheckedBaseModel):
    deployment_id: str
    environment_id: str
    deployment_config: EnvironmentDeploymentConfig
    created_at: dt.datetime
    created_by: Identity

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
